==> breeze_website_builder_6.5.02.tar.gz: manage/plugins/lang/gallery/nl.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Beheer Lightbox Gallary Parameters");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Manage Gallery");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Grote afbeelding Breedte");
define('MANAGE_GALLERY_FULL_HEIGHT', "Grote afbeelding Hoogte");
define('MANAGE_GALLERY_THUMB_WIDTH', "Minibild Breedte");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Minibild Hoogte");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Preserve Thumb Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Titles Show");
define('MANAGE_GALLERY_DISABLE_SORT', "uitschakelen Sort");
define('MANAGE_GALLERY_DELETE_IMAGE', "Afbeelding verwijderen");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Save Sorteervolgorde");
define('MANAGE_GALLERY_PUBLISH_MSG', "Klik op &#39;Bijwerken&#39; te publiceren <br /> uw geüploade afbeeldingen.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Alle foto&#39;s zijn aangepast en instellingen zijn opgeslagen.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Er is een fout de grootte van het beeld of het opslaan van instellingen.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Uw afbeelding (en) is geüpload.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Er is een fout opgetreden het uploaden van uw afbeelding (en).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Het bestand dat u probeert te uploaden is niet een beeld.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Het bestand dat u probeert te uploaden is te groot.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "De titel is opgeslagen.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Weet u zeker dat u het verwijderen");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Het beeld is verwijderd.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Er is een fout van de opname te wissen.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "parameters opslaan en resizen beelden, even geduld ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Uploaden, even geduld ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "De sorteervolgorde is niet opgeslagen. Wilt u de sorteervolgorde te redden?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Het beeld sorteervolgorde is opgeslagen.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Er is een fout opgetreden het opslaan van het beeld soort.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/nl.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Beheer Lightbox Gallary Parameters");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Manage Gallery");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Grote afbeelding Breedte");
define('MANAGE_GALLERY_FULL_HEIGHT', "Grote afbeelding Hoogte");
define('MANAGE_GALLERY_THUMB_WIDTH', "Minibild Breedte");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Minibild Hoogte");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Preserve Thumb Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Titles Show");
define('MANAGE_GALLERY_DISABLE_SORT', "uitschakelen Sort");
define('MANAGE_GALLERY_DELETE_IMAGE', "Afbeelding verwijderen");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Save Sorteervolgorde");
define('MANAGE_GALLERY_PUBLISH_MSG', "Klik op &#39;Bijwerken&#39; te publiceren <br /> uw geüploade afbeeldingen.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Alle foto&#39;s zijn aangepast en instellingen zijn opgeslagen.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Er is een fout de grootte van het beeld of het opslaan van instellingen.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Uw afbeelding (en) is geüpload.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Er is een fout opgetreden het uploaden van uw afbeelding (en).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Het bestand dat u probeert te uploaden is niet een beeld.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Het bestand dat u probeert te uploaden is te groot.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "De titel is opgeslagen.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Weet u zeker dat u het verwijderen");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Het beeld is verwijderd.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Er is een fout van de opname te wissen.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "parameters opslaan en resizen beelden, even geduld ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Uploaden, even geduld ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "De sorteervolgorde is niet opgeslagen. Wilt u de sorteervolgorde te redden?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Het beeld sorteervolgorde is opgeslagen.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Er is een fout opgetreden het opslaan van het beeld soort.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Het bestand dat u probeert te uploaden is groter dan de &#39;upload_max_filesize&#39; of de &#39;post_max_size&#39; PHP-instellingen. Neem contact op met uw systeembeheerder om deze limieten te verhogen.");
?>
